@@ -53,6 +53,6 @@ pub mod deserialize;
 pub mod consts;
 pub mod serialize;
 pub mod geom;
+pub mod key;
 
-pub use shape::ShapeType;
-pub use app::App;
+pub mod prelude;
